# Obscuratee™

_Reimagining terminal communication through marine-inspired innovation._

---

## 🚀 Executive Summary

At the intersection of marine biology, and questionable priorities, **Obscuratee** emerges as the premier platform for delivering **factually ambiguous aquatic knowledge** directly to your terminal.

> _"It's like if cowsay and pokemon-colorscripts had a child... just worse... and with a manatee..."_
> — Our beloved CTO

---

<br>

<p align="left" style="position: relative;">
  <img src="https://i.pinimg.com/736x/c4/42/14/c44214d9b54a70dcc4dfe274e3b3004e.jpg" alt="manatee" height="140" style="float: right; margin-left: 20px; margin-right: 20px;" />
</p>
<em style="display: block; margin-top: 60px; margin-left: 70px; text-align: left;">
    They write the facts. You just read them...
</em>

<br>

## 📦 Installation

**The ✨Fast Way✨ (pip)**

```bash
pip install obscuratee
```

Once installed, summon the fella:

```bash
obscuratee
```

~~Activate Vibe Mode™~~

```bash
 ̶o̶b̶s̶c̶u̶r̶a̶t̶e̶e̶ ̶-̶-̶v̶i̶b̶e̶
```

A̴̟̿c̶̖͗t̵̙̂ḭ̷͂v̵̝̈́à̶̦t̴̪͗e̶̢̋ C̴̗͐u̷̳̕r̴̓͜ş̸̔e̸̩̒ M̵͍͝o̵̜̅d̴̰̀ȇ̶͙™

```bash
obscuratee --curse
```

Use Legacy Mode (classic ASCII manatee):

```bash
obscuratee --legacy
```
